@@ -26,6 +26,34 @@ class TrtcClient(AbstractClient):
     _service = 'trtc'
 
 
+    def CreatePicture(self, request):
+        """上传图片
+
+        :param request: Request instance for CreatePicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.CreatePictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.CreatePictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreatePicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreatePictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateTroubleInfo(self, request):
         """创建异常信息
 
@@ -54,8 +82,36 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeletePicture(self, request):
+        """删除图片
+
+        :param request: Request instance for DeletePicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DeletePictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DeletePictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DeletePicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeletePictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeAbnormalEvent(self, request):
-        """查询SDKAppID下用户的异常体验事件，返回异常体验ID与可能产生异常体验的原因。可查询5天内数据，查询起止时间不超过1个小时。支持跨天查询。异常体验ID映射见：https://cloud.tencent.com/document/product/647/44916
+        """查询SDKAppID下用户的异常体验事件，返回异常体验ID与可能产生异常体验的原因。可查询15天内数据，查询起止时间不超过1个小时。支持跨天查询。异常体验ID映射见：https://cloud.tencent.com/document/product/647/44916
 
         :param request: Request instance for DescribeAbnormalEvent.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeAbnormalEventRequest`
@@ -167,8 +223,36 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribePicture(self, request):
+        """查询某图片相关参数。
+
+        :param request: Request instance for DescribePicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribePictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribePictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribePicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribePictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRealtimeNetwork(self, request):
-        """查询sdkappid维度下实时网络状态，包括上行丢包与下行丢包。可查询24小时内数据，查询起止时间不超过1个小时。
+        """查询sdkappid维度下每分钟实时网络状态，包括上行丢包与下行丢包。可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
 
         :param request: Request instance for DescribeRealtimeNetwork.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeNetworkRequest`
@@ -196,7 +280,7 @@ class TrtcClient(AbstractClient):
 
 
     def DescribeRealtimeQuality(self, request):
-        """查询sdkappid维度下实时质量数据，包括：进房成功率，首帧秒开率，音频卡顿率，视频卡顿率。可查询24小时内数据，查询起止时间不超过1个小时。
+        """查询sdkappid维度下每分钟实时质量数据，包括：进房成功率，首帧秒开率，音频卡顿率，视频卡顿率。可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
 
         :param request: Request instance for DescribeRealtimeQuality.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeQualityRequest`
@@ -224,7 +308,7 @@ class TrtcClient(AbstractClient):
 
 
     def DescribeRealtimeScale(self, request):
-        """查询sdkappid维度下实时规模，可查询24小时内数据，查询起止时间不超过1个小时。
+        """查询sdkappid维度下每分钟实时规模，可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
 
         :param request: Request instance for DescribeRealtimeScale.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeScaleRequest`
@@ -378,7 +462,7 @@ class TrtcClient(AbstractClient):
 
 
     def DescribeUserInformation(self, request):
-        """查询指定时间内的用户列表，可查询14天内数据。默认每页查询6个用户，支持每页最大查询100个用户PageSize不超过100）。
+        """查询指定时间内的用户列表，可查询14天内数据，查询起止时间不超过4小时。默认每页查询6个用户，支持每页最大查询100个用户PageSize不超过100）。
         注意：不建议依赖接口做实时类业务逻辑处理
 
         :param request: Request instance for DescribeUserInformation.
@@ -462,6 +546,34 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ModifyPicture(self, request):
+        """修改图片相关参数。
+
+        :param request: Request instance for ModifyPicture.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.ModifyPictureRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.ModifyPictureResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ModifyPicture", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ModifyPictureResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RemoveUser(self, request):
         """接口说明：将用户从房间移出，适用于主播/房主/管理员踢人等场景。支持所有平台，Android、iOS、Windows 和 macOS 需升级到 TRTC SDK 6.6及以上版本。
 
@@ -521,7 +633,7 @@ class TrtcClient(AbstractClient):
     def StartMCUMixTranscode(self, request):
         """接口说明：启动云端混流，并指定混流画面中各路画面的布局位置。
 
-        TRTC 的一个房间中可能会同时存在多路音视频流，您可以通过此 API 接口，通知腾讯云服务端将多路视频画面合成一路，并指定每一路画面的位置，同时将多路声音进行混音，最终形成一路音视频流，以便用于录制和直播观看。
+        TRTC 的一个房间中可能会同时存在多路音视频流，您可以通过此 API 接口，通知腾讯云服务端将多路视频画面合成一路，并指定每一路画面的位置，同时将多路声音进行混音，最终形成一路音视频流，以便用于录制和直播观看。房间销毁后混流自动结束。
 
         您可以通过此接口实现如下目标：
         - 设置最终直播流的画质和音质，包括视频分辨率、视频码率、视频帧率、以及声音质量等。
@@ -534,7 +646,7 @@ class TrtcClient(AbstractClient):
         - 九宫格模板：所有用户的视频画面大小一致，平分整个屏幕，人数越多，每个画面的尺寸越小。最多支持16个画面，如果用户只发送音频，仍然会占用画面位置。
         - 屏幕分享模板：适合视频会议和在线教育场景的布局，屏幕分享（或者主讲的摄像头）始终占据屏幕左侧的大画面位置，其他用户依次垂直排列于右侧，最多两列，每列最多8个小画面。最多支持1个大画面和15个小画面。若上行分辨率宽高比与画面输出宽高比不一致时，左侧大画面为了保持内容的完整性采用缩放方式处理，右侧小画面采用裁剪方式处理。
         - 画中画模板：适用于混合大小两路视频画面和其他用户混音，或者混合一路大画面和其他用户混音的场景。小画面悬浮于大画面之上，可以指定大小画面的用户以及小画面的显示位置，最多支持2个画面。
-        - 自定义模板：适用于在混流中指定用户的画面位置，或者预设视频画面位置的场景。当预设位置指定用户时，排版引擎会该用户预留位置；当预设位置未指定用户时，排版引擎会根据进房间顺序自动填充。用户只发送音频，仍然会占用画面位置，显示背景。预设位置填满时，不再混合其他用户的画面和声音。
+        - 自定义模板：适用于在混流中指定用户的画面位置，或者预设视频画面位置的场景。当预设位置指定用户时，排版引擎会该用户预留位置；当预设位置未指定用户时，排版引擎会根据进房间顺序自动填充。预设位置填满时，不再混合其他用户的画面和声音。自定义模板启用占位图功能时（LayoutParams中的PlaceHolderMode设置成1），在预设位置的用户没有上行视频时可显示对应的占位图（PlaceImageId）。
 
         注意：2020年1月9号及以后创建的应用才能直接调用此接口。2020年1月9日之前创建的应用默认使用云直播的云端混流，如需切换至MCU混流，请[提交工单](https://console.cloud.tencent.com/workorder/category)寻求帮助。
 
@@ -579,7 +691,7 @@ class TrtcClient(AbstractClient):
         - 九宫格模板：所有用户的视频画面大小一致，平分整个屏幕，人数越多，每个画面的尺寸越小。最多支持16个画面，如果用户只发送音频，仍然会占用画面位置。
         - 屏幕分享模板：适合视频会议和在线教育场景的布局，屏幕分享（或者主讲的摄像头）始终占据屏幕左侧的大画面位置，其他用户依次垂直排列于右侧，最多两列，每列最多8个小画面。最多支持1个大画面和15个小画面。若上行分辨率宽高比与画面输出宽高比不一致时，左侧大画面为了保持内容的完整性采用缩放方式处理，右侧小画面采用裁剪方式处理。
         - 画中画模板：适用于混合大小两路视频画面和其他用户混音，或者混合一路大画面和其他用户混音的场景。小画面悬浮于大画面之上，可以指定大小画面的用户以及小画面的显示位置。
-        - 自定义模板：适用于在混流中指定用户的画面位置，或者预设视频画面位置的场景。当预设位置指定用户时，排版引擎会该用户预留位置；当预设位置未指定用户时，排版引擎会根据进房间顺序自动填充。用户只发送音频，仍然会占用画面位置，显示背景。预设位置填满时，不再混合其他用户的画面和声音。
+        - 自定义模板：适用于在混流中指定用户的画面位置，或者预设视频画面位置的场景。当预设位置指定用户时，排版引擎会该用户预留位置；当预设位置未指定用户时，排版引擎会根据进房间顺序自动填充。预设位置填满时，不再混合其他用户的画面和声音。自定义模板启用占位图功能时（LayoutParams中的PlaceHolderMode设置成1），在预设位置的用户没有上行视频时可显示对应的占位图（PlaceImageId）。
 
         注意：2020年1月9号及以后创建的应用才能直接调用此接口。2020年1月9日之前创建的应用默认使用云直播的云端混流，如需切换至MCU混流，请[提交工单](https://console.cloud.tencent.com/workorder/category)寻求帮助。
 
